/* Mother of all config.h files for gerbv
 *
 *  gEDA - GNU Electronic Design Automation
 *  This file is part of gerbv.
 *
 *    Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
 *
 *  $Id: acconfig.h,v 1.6 2003/03/18 21:53:08 spetm Exp $
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
 */

/* Support for export of PNG's */
#undef EXPORT_PNG

/* Maximum number of simultaneous loaded files */
#undef MAX_FILES

/* Default unit to display in status bar */
#undef GERBV_DEFAULT_UNIT

/* Header files */
#undef HAVE_UNISTD_H
#undef HAVE_GETOPT_H
#undef HAVE_STRING_H

/* Long options */
#undef HAVE_GETOPT_LONG

/* Backend dir */
#undef BACKEND_DIR

/* Program version */
#undef VERSION
